@@ -106,20 +106,20 @@ end subroutine
 
 !--------------------------------------------------------
 
-subroutine ust_horizon( cm, va, velst )
+subroutine ust_horizon( cmd, va, velst )
 ! ໤® u_* ׻롼
   use Thermo_Advanced_Function
   implicit none
-  real, intent(in), dimension(:,:) :: cm  !  za ǤΥХ륯
-  real, intent(in), dimension(size(cm,1),size(cm,2)) :: va  !  za Ǥοʿ [m/s]
-  real, intent(inout), dimension(size(cm,1),size(cm,2)) :: velst  ! ໤® [m/s]
+  real, intent(in), dimension(:,:) :: cmd  !  za ǤΥХ륯
+  real, intent(in), dimension(size(cmd,1),size(cmd,2)) :: va  !  za Ǥοʿ [m/s]
+  real, intent(inout), dimension(size(cmd,1),size(cmd,2)) :: velst  ! ໤® [m/s]
   integer :: i, j, nx, ny
 
 !$omp parallel default(shared)
 !$omp do private(i,j)
      do j=1,ny
         do i=1,nx
-           velst(i,j)=ust( cm(i,j), va(i,j) )
+           velst(i,j)=ust( cmd(i,j), va(i,j) )
         end do
      end do
 !$omp end do
