@@ -78,13 +78,13 @@ end function
 !--------------------------------------------------------
 !--------------------------------------------------------
 
-real function ust( cm, va )
+real function ust( cmd, va )
 ! ໤® u_* ׻ؿ
   implicit none
-  real, intent(in) :: cm  !  za ǤΥХ륯
+  real, intent(in) :: cmd  !  za ǤΥХ륯
   real, intent(in) :: va  !  za Ǥοʿ [m/s]
 
-  ust=va*sqrt(cm)
+  ust=va*sqrt(cmd)
 
 end function
 
